Feedforward Closedloop Learning: Member List

Feedforward Closedloop Learning

Neuron Member List

This is the complete list of members for Neuron, including all inherited members.

ActivationFunction enum name | Neuron |
calcOutput() | Neuron |
calcOutputThread(void *object) | Neuron | inlinestatic
CONST_WEIGHTS enum value (defined in Neuron) | Neuron |
dActivation() | Neuron |
doLearning() | Neuron |
doLearningThread(void *object) | Neuron | inlinestatic
doMaxDet() | Neuron |
doMaxDetThread(void *object) | Neuron | inlinestatic
getAverageOfWeightVector() | Neuron |
getBiasWeight() | Neuron | inline
getDecay() | Neuron | inline
getError() | Neuron | inline
getEuclideanNormOfWeightVector() | Neuron | inline
getInfinityNormOfWeightVector() | Neuron |
getInput(int _index) | Neuron | inline
getManhattanNormOfWeightVector() | Neuron |
getMask(int x, int y) | Neuron |
getMask(int index) | Neuron | inline
getMaxWeightValue() | Neuron |
getMinWeightValue() | Neuron |
getNinputs() | Neuron | inline
getOutput() | Neuron | inline
getSum() | Neuron | inline
getSumOfSquaredWeightVector() | Neuron |
getWeight(int _index) | Neuron | inline
getWeightDistanceFromInitialWeights() | Neuron |
initWeights(double _max=1, int initBias=1, WeightInitMethod _wm=MAX_OUTPUT_RANDOM) | Neuron |
LINEAR enum value (defined in Neuron) | Neuron |
MAX_OUTPUT_CONST enum value (defined in Neuron) | Neuron |
MAX_OUTPUT_RANDOM enum value (defined in Neuron) | Neuron |
MAX_WEIGHT_RANDOM enum value (defined in Neuron) | Neuron |
Neuron(int _nInputs) | Neuron |
normaliseWeights(double norm) | Neuron |
RELU enum value (defined in Neuron) | Neuron |
REMAXLU enum value (defined in Neuron) | Neuron |
saveInitialWeights() | Neuron |
setActivationFunction(ActivationFunction _activationFunction) | Neuron | inline
setBias(double _bias) | Neuron | inline
setBiasWeight(double _biasweight) | Neuron | inline
setDebugInfo(int _layerIndex, int _neuronIndex) | Neuron | inline
setDecay(double _decay) | Neuron | inline
setError(double _error) | Neuron |
setGeometry(int _width, int _height) | Neuron | inline
setInput(int _index, double _value) | Neuron | inline
setLearningRate(double _learningrate) | Neuron | inline
setMask(int x, int y, unsigned char c) | Neuron |
setMask(unsigned char c) | Neuron |
setMomentum(double _momentum) | Neuron | inline
setStep(long int _step) | Neuron | inline
setWeight(int _index, double _weight) | Neuron | inline
TANH enum value (defined in Neuron) | Neuron |
TANHLIMIT enum value (defined in Neuron) | Neuron |
WeightInitMethod enum name | Neuron |
~Neuron() | Neuron |